Calculate Significant Wave Height from Raw Elevations
calculate_hs_from_elevation.RdCalculates Hs from a time series of surface elevation measurements using the spectral method (4 * sigma).
calculate_hs_from_elevation.RdCalculates Hs from a time series of surface elevation measurements using the spectral method (4 * sigma).