Create a validation summary for the pipeline
create_validation_summary.RdGenerates a summary of all validation results that can be included in dashboards or reports.
create_validation_summary.RdGenerates a summary of all validation results that can be included in dashboards or reports.