Skip to contents

Functions for detecting and analyzing rogue waves from buoy data. Rogue waves are defined as waves where Hmax > threshold * WaveHeight.

Standard definition: Hmax > 2.0 * significant wave height Extreme definition: Hmax > 2.2 * significant wave height Detect Rogue Waves in Buoy Data

Identifies rogue wave events based on the ratio of maximum wave height (Hmax) to significant wave height (WaveHeight). Uses dplyr verbs translated to SQL for efficient DuckDB execution.

Usage

detect_rogue_waves(
  con,
  threshold = 2,
  min_wave_height = 2,
  start_date = NULL,
  end_date = NULL,
  stations = NULL
)

Arguments

con

DBI connection to DuckDB database

threshold

Hmax/WaveHeight ratio threshold (default: 2.0)

min_wave_height

Minimum significant wave height to consider (default: 2m)

start_date

Optional start date filter

end_date

Optional end date filter

stations

Optional vector of station IDs to filter

Value

Data frame of rogue wave events with associated conditions

Examples

if (FALSE) { # \dontrun{
con <- connect_duckdb()
rogues <- detect_rogue_waves(con, threshold = 2.0)
DBI::dbDisconnect(con)
} # }