Estimate Hs from RMS Wave Height
hs_from_rms.RdConverts RMS wave height to significant wave height using the theoretical relationship for Rayleigh-distributed waves.
hs_from_rms.RdConverts RMS wave height to significant wave height using the theoretical relationship for Rayleigh-distributed waves.