Convert Wind Speed in Knots to Beaufort Scale
knots_to_beaufort.RdVectorized conversion from wind speed in knots to the Beaufort scale (0-12).
Examples
knots_to_beaufort(c(0, 5, 20, 34, 48, 64))
#> [1] 0 2 5 8 10 12
knots_to_beaufort.RdVectorized conversion from wind speed in knots to the Beaufort scale (0-12).
knots_to_beaufort(c(0, 5, 20, 34, 48, 64))
#> [1] 0 2 5 8 10 12