Analyze Gust Factor
analyze_gust_factor.RdAnalyzes the ratio of peak gust to sustained wind speed. This is the wind equivalent of the wave Hmax/Hs ratio.
Value
List with:
summary: summary statistics of gust factor
extreme_gusts: observations with high gust factors
by_wind_category: gust factor by wind speed category
Examples
if (FALSE) { # \dontrun{
con <- connect_duckdb()
data <- query_buoy_data(con, variables = c("time", "wind_speed", "gust"))
gust_analysis <- analyze_gust_factor(data)
DBI::dbDisconnect(con)
} # }