Rogue Wave Detection and Analysis
detect_rogue_waves.RdFunctions for detecting and analyzing rogue waves from buoy data. Rogue waves are defined as waves where Hmax > threshold * WaveHeight.
Standard definition: Hmax > 2.0 * significant wave height Extreme definition: Hmax > 2.2 * significant wave height Detect Rogue Waves in Buoy Data
Identifies rogue wave events based on the ratio of maximum wave height (Hmax) to significant wave height (WaveHeight). Uses dplyr verbs translated to SQL for efficient DuckDB execution.
Usage
detect_rogue_waves(
con,
threshold = 2,
min_wave_height = 2,
start_date = NULL,
end_date = NULL,
stations = NULL
)Examples
if (FALSE) { # \dontrun{
con <- connect_duckdb()
rogues <- detect_rogue_waves(con, threshold = 2.0)
DBI::dbDisconnect(con)
} # }