Skip to contents

This function returns a comprehensive data dictionary for all variables available in the Irish Weather Buoy Network dataset. Each entry includes the variable name, units, data type, description, and typical range.

Usage

get_data_dictionary()

Value

A data frame containing the complete data dictionary with columns:

  • variable: Variable name as used in the dataset

  • category: Category (dimension, meteorological, oceanographic, quality)

  • units: Measurement units

  • data_type: R data type

  • description: Detailed description of the variable

  • typical_range: Typical or valid range of values

Examples

dict <- get_data_dictionary()
print(dict)
#> # A tibble: 22 × 6
#>    variable            category       units  data_type description typical_range
#>    <chr>               <chr>          <chr>  <chr>     <chr>       <chr>        
#>  1 station_id          dimension      NA     character Unique ide… M1, M2, M3, …
#>  2 CallSign            dimension      NA     character Internatio… Various      
#>  3 longitude           dimension      degre… numeric   Geographic… -15.88 to -5…
#>  4 latitude            dimension      degre… numeric   Geographic… 51.22 to 55.…
#>  5 time                dimension      secon… POSIXct   Timestamp … 2002-present 
#>  6 AtmosphericPressure meteorological milli… numeric   Atmospheri… 970-1030     
#>  7 AirTemperature      meteorological degre… numeric   Air temper… -10 to 30    
#>  8 DewPoint            meteorological degre… numeric   Dew point … -15 to 25    
#>  9 WindDirection       meteorological degre… numeric   Direction … 0-360        
#> 10 WindSpeed           meteorological knots  numeric   Average wi… 0-60         
#> # ℹ 12 more rows